===
Piu
===

.. image:: https://travis-ci.org/zalando-stups/piu.svg?branch=master
   :target: https://travis-ci.org/zalando-stups/piu

.. image:: https://coveralls.io/repos/zalando-stups/piu/badge.svg
   :target: https://coveralls.io/r/zalando-stups/piu

Piu is the command line client for the "even" SSH access granting service.

Installation
============

.. code-block:: bash

    $ sudo pip3 install --upgrade stups-piu

Usage
=====

.. code-block:: bash

    $ piu myuser@myhost my-reason

